@@ -10,13 +10,12 @@ use strict;
 use warnings;
 
 package StorageDisplay::Collect;
-# ABSTRACT: modules required to collect data. No dependencies (but perl itself)
+# ABSTRACT: modules required to collect data.
+# No dependencies (but perl itself and its basic modules)
 
-our $VERSION = '1.1.0'; # VERSION
+our $VERSION = '1.1.1'; # VERSION
 
 
-use Storable;
-
 sub collectors {
     my $self = shift;
     return @{$self->{_attr_collectors}};
@@ -194,6 +193,108 @@ sub collect {
 
 1;
 
+###########################################################################
+package StorageDisplay::Collect::JSON;
+
+BEGIN {
+    # Mark current package as loaded;
+    my $p = __PACKAGE__;
+    $p =~ s,::,/,g;
+    chomp(my $cwd = `pwd`);
+    $INC{$p.'.pm'} = $cwd.'/'.__FILE__;#k"current file";
+}
+
+use base 'JSON::PP';
+
+my $has_boolean_values;
+
+my $json_pp_parser;
+
+sub create_json_pp_parser {
+    if (defined($json_pp_parser)) {
+	die "Internal error: create_json_pp_parser already called";
+    }
+    $json_pp_parser = JSON::PP->new;
+    eval {
+	# ignore if not supported
+        $json_pp_parser->allow_bignum;
+    };
+    $has_boolean_values = 0;
+    eval {
+	# workaround if not supported
+	$json_pp_parser->boolean_values(0, 1);
+	$has_boolean_values = 1;
+    };
+    return $json_pp_parser;
+}
+
+my $json_parser;
+
+sub create_json_parser {
+    if (defined($json_parser)) {
+	die "Internal error: create_json_parser already called";
+    }
+    if (not defined($json_pp_parser)) {
+	die "Internal error: json_pp_parser not available";
+    }
+    if ($has_boolean_values) {
+	return $json_pp_parser;
+    }
+    $json_parser =  StorageDisplay::Collect::JSON->new();
+}
+
+sub decode {
+    my $self = shift;
+
+    my $data = $json_pp_parser->decode(@_);
+
+    my %unrecognized;
+
+    local *_convert_bools = sub {
+        my $ref_type = ref($_[0]);
+        if (!$ref_type) {
+            # Nothing.
+        }
+        elsif ($ref_type eq 'HASH') {
+            _convert_bools($_) for values(%{ $_[0] });
+        }
+        elsif ($ref_type eq 'ARRAY') {
+            _convert_bools($_) for @{ $_[0] };
+        }
+        elsif (
+               $ref_type eq 'JSON::PP::Boolean'           # JSON::PP
+            || $ref_type eq 'Types::Serialiser::Boolean'  # JSON::XS
+        ) {
+            $_[0] = $_[0] ? 1 : 0;
+        }
+        else {
+            ++$unrecognized{$ref_type};
+        }
+    };
+
+    &_convert_bools($data);
+
+    warn("Encountered an object of unrecognized type $_")
+        for sort values(%unrecognized);
+
+    return $data;
+}
+
+sub decode_json {
+    if (not defined($json_parser)) {
+	$json_pp_parser = create_json_pp_parser();
+	$json_parser = create_json_parser();
+    }
+
+    $json_parser->decode(@_);
+}
+
+sub use_pp_parser {
+    return $has_boolean_values;
+}
+
+1;
+
 ###########################################################################
 package StorageDisplay::Collect::CMD;
 
@@ -573,21 +674,15 @@ use is_collector
         progs => [ 'lsblk', 'udevadm' ],
 };
 
-use JSON::PP;
+use StorageDisplay::Collect::JSON;
 
 sub lsblkjson2perl {
     my $self = shift;
     my $json = shift;
-    my $jsonparser = JSON::PP->new;
-    eval {
-        $jsonparser->allow_bignum;
-    };
-    eval {
-        $jsonparser->boolean_values([0, 1]);
-    };
     my $info = {
         map { $_->{kname} => $_ }
-            (@{$jsonparser->decode($json)->{"blockdevices"}})
+	(@{StorageDisplay::Collect::JSON::decode_json($json)
+	       ->{"blockdevices"}})
     };
     return $info;
 }
@@ -890,7 +985,7 @@ use is_collector
         root => 1,
 };
 
-use JSON::PP;
+use StorageDisplay::Collect::JSON;
 
 sub lvmjson2perl {
     my $self = shift;
@@ -900,14 +995,8 @@ sub lvmjson2perl {
     my $keys = shift;
     my $info = shift // {};
     my $json = shift;
-    my $jsonparser = JSON::PP->new;
-    eval {
-        $jsonparser->allow_bignum;
-    };
-    eval {
-        $jsonparser->boolean_values([0, 1]);
-    };
-    my $alldata = $jsonparser->decode($json)->{'report'}->[0]->{$kind};
+    my $alldata = StorageDisplay::Collect::JSON::decode_json($json)
+	->{'report'}->[0]->{$kind};
     foreach my $data (@$alldata) {
         my $vg=$data->{vg_name} // die "no vg_name in data!";
         my $base = $info->{$vg}->{$kstore};
@@ -1775,16 +1864,19 @@ __END__
 
 =head1 NAME
 
-StorageDisplay::Collect - modules required to collect data. No dependencies (but perl itself)
+StorageDisplay::Collect - modules required to collect data.
 
 =head1 VERSION
 
-version 1.1.0
+version 1.1.1
 
 Main class, allows one to register collectors and run them (through the collect method)
 
 Collectors will be registered when their class is loaded
 
+Wrapper around JSON:PP as old versions do not support the
+boolean_value method.
+
 Base (abstract) class to run command to collect infos
 
 Only one instance should be created
