@@ -12,7 +12,7 @@ use warnings;
 package StorageDisplay::Data::Root;
 # ABSTRACT: Handle machine data for StorageDisplay
 
-our $VERSION = '1.1.0'; # VERSION
+our $VERSION = '1.1.1'; # VERSION
 
 use Moose;
 use namespace::sweep;
@@ -67,7 +67,7 @@ sub dotSubGraph {
 	{
 	    # No consumed block. Perhaps, we come from a VM provisionning
 	    my @blocks = grep {
-		!$_->provided
+		(($_->provided && $_->elem->isa('StorageDisplay::Data::Partition::None')) || !$_->provided)
 		    && $_->isa('StorageDisplay::Block::System')
 	    } $e->consumedBlocks;
 	    $self->pushDotText(
@@ -119,7 +119,7 @@ StorageDisplay::Data::Root - Handle machine data for StorageDisplay
 
 =head1 VERSION
 
-version 1.1.0
+version 1.1.1
 
 =head1 AUTHOR
 
